@@ -278,6 +278,9 @@ sub spf_check ($$$) {
   my ($sth, $private, $params) = @_;
 
   return "dunno" if ($params->{request} ne "smtpd_access_policy");
+  foreach (qw(sender client_address)) {
+    return "dunno" if !$params->{$_};
+  }
 
   if (!$$private) {
     $$private = Mail::SPF::Server->new();
@@ -313,6 +316,9 @@ sub spf_helo_check ($$$) {
   my ($sth, $private, $params) = @_;
 
   return "dunno" if ($params->{request} ne "smtpd_access_policy");
+  foreach (qw(helo_name client_address)) {
+    return "dunno" if !$params->{$_};
+  }
 
   if (!$$private) {
     $$private = Mail::SPF::Server->new();
